osrm_check_available_versions: Check for Available OSRM Versions

View source: R/osrm_install.R

osrm_check_available_versionsR Documentation

Check for Available OSRM Versions

Description

[Stable]

Queries the GitHub API to get a list of all available version tags for the OSRM backend that have binaries for the current platform.

Usage

osrm_check_available_versions(prereleases = FALSE)

Arguments

prereleases

A logical value. If TRUE, include pre-release versions in the returned list. Defaults to FALSE.

Value

A character vector of available version tags.

Examples


if (identical(Sys.getenv("OSRM_EXAMPLES"), "true")) {
  # Get all stable versions with binaries for this platform
  osrm_check_available_versions()
}


osrm.backend documentation built on April 26, 2026, 9:06 a.m.