View source: R/osrm_uninstall.R
| osrm_uninstall | R Documentation |
Removes the OSRM backend binaries and optionally clears the PATH
configuration from the project's .Rprofile.
osrm_uninstall(
dest_dir = NULL,
clear_path = TRUE,
quiet = FALSE,
all = FALSE,
force = FALSE
)
dest_dir |
A string specifying the directory from which to remove OSRM binaries.
If |
clear_path |
A logical value. If |
quiet |
A logical value. If |
all |
A logical value. If |
force |
A logical value. If |
TRUE if one or more directories were successfully removed,
and FALSE otherwise.
if (identical(Sys.getenv("OSRM_EXAMPLES"), "true")) {
# Install OSRM temporarily
install_dir <- osrm_install(path_action = "session", quiet = TRUE)
# Uninstall that specific version and clear PATH changes
osrm_uninstall(
dest_dir = install_dir,
clear_path = TRUE,
force = TRUE,
quiet = TRUE
)
# If multiple installs exist, remove them all
osrm_uninstall(all = TRUE, force = TRUE, quiet = TRUE)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.