| osrm_check_available_versions | R Documentation |
Queries the GitHub API to get a list of all available version tags for the OSRM backend that have binaries for the current platform.
osrm_check_available_versions(prereleases = FALSE)
prereleases |
A logical value. If |
A character vector of available version tags.
if (identical(Sys.getenv("OSRM_EXAMPLES"), "true")) {
# Get all stable versions with binaries for this platform
osrm_check_available_versions()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.