powered by
Queries the GitHub API to get a list of all available version tags for the OSRM backend that have binaries for the current platform.
osrm_check_available_versions(prereleases = FALSE)
A character vector of available version tags.
A logical value. If TRUE, include pre-release versions in the returned list. Defaults to FALSE.
TRUE
FALSE
# \donttest{ if (identical(Sys.getenv("OSRM_EXAMPLES"), "true")) { # Get all stable versions with binaries for this platform osrm_check_available_versions() } # }
Run the code above in your browser using DataLab