View source: R/osrm_server_registry.R
| osrm_get_server_profile | R Documentation |
Attempts to determine the profile (e.g., "car", "bike", "foot") used by an OSRM server. It follows a priority list:
Checks the active server registry for the given port or ID.
Checks for a dataset.meta.json file in the directory of the graph file.
Checks the graph filename for hints (e.g. berlin-car.osrm).
Falls back to getOption("osrm.profile").
osrm_get_server_profile(input_osrm = NULL, port = NULL)
input_osrm |
Optional. Can be an OSRM job process (an |
port |
Optional integer. The port of the server. |
A character string representing the profile name (default "car").
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.